@@ -1,6 +1,6 @@
 package Gapp::Form::Stash;
 {
-  $Gapp::Form::Stash::VERSION = '0.494';
+  $Gapp::Form::Stash::VERSION = '0.60';
 }
 
 use Moose;
@@ -48,6 +48,7 @@ sub update {
             my $value = $cx->lookup( $field );
             $self->store( $field, $value );
         }
+        
        
     }
     
@@ -57,7 +58,7 @@ sub update {
 sub update_from_context {
     my $self = shift;
     use Carp qw( cluck );
-    cluck '$stash->update_from_context( $cx ) deprecated, use $stah->update( $cx ) instead';
+    cluck '$stash->update_from_context( $cx ) deprecated, use $stash->update( $cx ) instead';
     $self->update( @_ );
 }
 
