@@ -1,6 +1,6 @@
 package Gapp::Gtk2::Model::List;
 {
-  $Gapp::Gtk2::Model::List::VERSION = '0.494';
+  $Gapp::Gtk2::Model::List::VERSION = '0.60';
 }
 
 use Glib qw(TRUE FALSE);
@@ -17,6 +17,7 @@ use Glib::Object::Subclass
 
 sub INIT_INSTANCE {
 	my $self = shift;
+	$self->{column_types} = [ 'Glib::Scalar' ];
 	$self->{rows}     = [];
 	$self->{stamp} = sprintf '%d', rand (1<<31);
 }
@@ -30,7 +31,7 @@ sub FINALIZE_INSTANCE {
 
 
 sub GET_FLAGS { [qw/list-only/] }
-sub GET_N_COLUMNS { undef }
+sub GET_N_COLUMNS { 0 }
 
 sub GET_COLUMN_TYPE {
     my ($self, $index) = @_;
