@@ -1,6 +1,6 @@
 package Gapp::Label;
 {
-  $Gapp::Label::VERSION = '0.494';
+  $Gapp::Label::VERSION = '0.60';
 }
 
 use Moose;
@@ -61,7 +61,7 @@ sub BUILDARGS {
     
     
     
-    for my $att ( qw( xalign yalign) ) {
+    for my $att ( qw( angle ellipsize cursor_position max_width_chars mnemonic_keyval pattern selectable selection_bound single_line_mode track_visited_links use_markup use_underline width_chars wrap wrap_mode xalign yalign justify  ) ) {
         $args{properties}{$att} = delete $args{$att} if exists $args{$att};
     }
     
