@@ -1,6 +1,6 @@
 package Gapp::Toolbar;
 {
-  $Gapp::Toolbar::VERSION = '0.494';
+  $Gapp::Toolbar::VERSION = '0.60';
 }
 
 use Moose;
@@ -16,7 +16,7 @@ sub BUILDARGS {
     my $class = shift;
     my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
     
-    for my $att ( qw(toolbar_style show_arrow tooltips ) ) {
+    for my $att ( qw(toolbar_style show_arrow tooltips orientation ) ) {
         $args{properties}{$att} = delete $args{$att} if exists $args{$att};
     }
     if ( exists $args{style} ) {
